@@ -48,7 +48,8 @@ def main(argv=sys.argv[1:]):
         miura_script = MiuraScript(options['<script_name>'],
                                    DATA_DIRECTORY,
                                    SCRIPTS_DIRECTORY,
-                                   TEMPLATE_DIRECTORY)
+                                   TEMPLATE_DIRECTORY,
+                                   data_filters=filters)
         if options['--delete']:
             miura_script.delete = True
         if options['--dry-run']:
