@@ -1,6 +1,10 @@
-import yaml
 import os
+import re
+import yaml
 from .exceptions import MiuraException
+import logging
+
+logger = logging.getLogger(__name__)
 
 
 def load_data_from_path(path):
@@ -34,14 +38,32 @@ def retrieve_data(file_paths):
         with open(file_path) as fh:
             try:
                 content = yaml.load(fh.read())
-            except yaml.parser.ParserError as e:
+            except yaml.YAMLError as e:
                 raise MiuraException(
                     "Unable to parse yaml at {0}: \n {1}".format(
                         file_path,
                         str(e)
                     ))
-
-            assert isinstance(content, dict), \
-                "{0} is does not translate to a dictionary!".format(file_path)
+            if not isinstance(content, dict):
+                raise MiuraException(
+                    "{0} is does not translate to a dictionary!".format(file_path)
+                )
             data_dict.update(content)
     return data_dict
+
+
+def filter_data(data, filter_dict):
+    """ filter a data dictionary for values only matching the filter """
+    for key, match_string in filter_dict.items():
+        if key not in data:
+            logger.warning("{0} doesn't match a top level key".format(key))
+            continue
+        values = data[key]
+        matcher = re.compile(match_string)
+        if isinstance(values, list):
+            values = [v for v in values if matcher.search(v)]
+        elif isinstance(values, dict):
+            values = dict((k, v) for k, v in values.items() if matcher.search(k))
+        else:
+            raise MiuraException("cannot filter a {0}".format(type(values)))
+        data[key] = values
